@@ -104,13 +104,16 @@ int decode_DIS_JobCred(sock, preq)
 	struct batch_request *preq;
 {
 	int rc;
+	size_t rqsize;
 
 	preq->rq_ind.rq_jobcred.rq_data = 0;
 	preq->rq_ind.rq_jobcred.rq_type = disrui(sock, &rc);
 	if (rc) return rc;
 
 	preq->rq_ind.rq_jobcred.rq_data = disrcs(sock,
-			         (size_t *)&preq->rq_ind.rq_jobcred.rq_size, 
+			         &rqsize, 
 				 &rc);
+	preq->rq_ind.rq_jobcred.rq_size=rqsize;
+
 	return rc;
 }
