@@ -93,6 +93,17 @@
 
 extern int decode_null A_((attribute *patr, char *name, char *rn, char *val));
 extern int set_null A_((attribute *patr, attribute *new, enum batch_op op));
+extern int disallowed_types_chk A_((attribute *pattr, void *pobject, int actmode));
+
+/* array of allowable strings in queue attribute disallowed_types */
+char* array_disallowed_types[] = {
+   Q_DT_batch,
+   Q_DT_interactive,
+   Q_DT_rerunable,
+   Q_DT_nonrerunable,
+   "_END_" /* must be last string */
+};
+
 
 /*
  * The entries for each attribute are (see attribute.h):
@@ -340,7 +351,7 @@ attribute_def que_attr_def[] = {
        ATR_TYPE_LONG,
        PARENT_TYPE_QUE_ALL
      },
-/* QS_ATR_MTime */
+/* QA_ATR_MTime */
     {	ATTR_mtime,		/* "mtime" */
 	decode_l,
 	encode_l,
@@ -352,6 +363,19 @@ attribute_def que_attr_def[] = {
 	ATR_TYPE_LONG,
 	PARENT_TYPE_QUE_ALL
     },
+/* QA_ATR_DisallowedTypes */
+    {   ATTR_disallowedtypes,   /* "disallowed_types" */
+        decode_arst,
+        encode_arst,
+        set_arst,
+        comp_arst,
+        free_arst,
+        disallowed_types_chk,
+        NO_USER_SET,
+        ATR_TYPE_ACL,
+        PARENT_TYPE_QUE_ALL
+    },
+
 
    /* for execution queues only */
 
