@@ -667,7 +667,7 @@ void on_job_exit(
 
   {
   int    handle;
-  job   *pjob, *pj;
+  job   *pjob;
   struct batch_request *preq;
 
   int    IsFaked = 0;
@@ -689,38 +689,6 @@ void on_job_exit(
     pjob = (job *)preq->rq_extra;
     }
 
-#ifdef VNODETESTING
-/* FIXME: there might be a race with calling on_job_exit after a job has
- * already been free'd.  This is temp code */
-  pj = (job *)GET_NEXT(svr_alljobs);
-  
-  while (pj != NULL)
-    {
-    if (pjob==pj)
-      break;
-    
-    pj = (job *)GET_NEXT(pj->ji_alljobs);
-    }
-  
-  if (pj==NULL)
-    {
-    sprintf(log_buffer,"on_job_exit called with INVALID pjob: %p",pjob);
-    }
-  else
-    {
-    sprintf(log_buffer,"on_job_exit valid pjob: %p (substate=%d)",pjob,pjob->ji_qs.ji_substate);
-    }
-
-  log_event(
-    PBSEVENT_JOB,
-    PBS_EVENTCLASS_JOB,
-    pjob->ji_qs.ji_jobid,
-    log_buffer);
-
-  DBPRT(("%s\n",log_buffer));
-#endif
-
-
   if ((handle = mom_comm(pjob, on_job_exit)) < 0)
     {
     return;
